@@ -5,7 +5,7 @@ test_relop_drop_columns <- function() {
  rquery_pipeline <- local_td(dL) %.>%
    drop_columns(., "y")
  res <- ex_data_table(rquery_pipeline)
- RUnit::checkTrue(data.table::is.data.table(res))
+ RUnit::checkTrue(is.data.frame(res))
  RUnit::checkTrue(!('y' %in% colnames(res)))
 
  invisible(NULL)
