@@ -8,7 +8,7 @@ test_relop_table_source <- function() {
      1L , "a" |
      3L , "c" )
  rquery_pipeline <- local_td(dL)
- ex_data_table(rquery_pipeline)[]
+ ex_data_table(rquery_pipeline)
 
  invisible(NULL)
 }
