@@ -4,10 +4,10 @@ test_select_narrowing <- function() {
   x <- data.frame(a = 1:3, b = 4:6, c = 7:9)
   op1 <- local_td(x) %.>% extend_nse(., e %:=% a + 1)
   #  cat(to_sql(op1, dbinfo))
-  cn1 <- sort(colnames((x %.>% op1)[]))
+  cn1 <- sort(colnames((x %.>% op1)))
   op2 <- op1 %.>% select_columns(., "e")
   #  cat(to_sql(op2, dbinfo))
-  cn2 <- sort(colnames((x %.>% op2)[]))
+  cn2 <- sort(colnames((x %.>% op2)))
   RUnit::checkEquals(cn1, c("a", "b", "c", "e"))
   RUnit::checkEquals(cn2, c("e"))
 
